==> lnl-2.1.10.tar.gz: lnl-2.1.10/src/msg.c <==
/*#include	<stddef.h>*/
/*#include	<stdio.h>*/
#include	<string.h>
/*#include	<ctype.h>*/
/*#include	<time.h>*/
/*#include	<sys/stat.h>*/

#include	"gmain.h"
/*#include	"dun.h"*/
/*#include	"town.h"*/
/*#include	"item.h"*/
/*#include	"spell.h"*/
/*#include	"chr.h"*/
/*#include	"party.h"*/
/*#include	"mnstr.h"*/
/*#include	"fight.h"*/
/*#include	"fx.h"*/
/*#include	"trap.h"*/
#include	"draw.h"
/*#include	"curs.h"*/
/*#include	"menu.h"*/
#include	"msg.h"
/*#include	"ver.h"*/
#include	"gmain_prot.h"
/*#include	"dun_prot.h"*/
/*#include	"town_prot.h"*/
/*#include	"item_prot.h"*/
/*#include	"spell_prot.h"*/
/*#include	"chr_prot.h"*/
/*#include	"party_prot.h"*/
/*#include	"mnstr_prot.h"*/
/*#include	"fight_prot.h"*/
/*#include	"fx_prot.h"*/
/*#include	"trap_prot.h"*/
#include	"draw_prot.h"
/*#include	"curs_prot.h"*/
/*#include	"menu_prot.h"*/
/*#include	"tmenu_prot.h"*/
/*#include	"amenu_prot.h"*/
/*#include	"gfile_prot.h"*/
/*#include	"msg_prot.h"*/

/**/

#define	STR_DFLT_LANG	STR_JP_EUC

#define	STR_S	"%s"
#define	STR_ENV_LANG	"LANG"
#define	STR_ENGLISH	"C"
#define	STR_JP_EUC	"ja_JP.eucJP"
#define	STR_JP_UJIS	"ja_JP.ujis"
#define	STR_SUPPORT_LANG	"Supporting language is:"
#define	STR_SUPPORT_LANG_LIST	"\t`%s'\n"
#define	STR_ERR_LANG	"Don't support language: LANG=%s"
#define	STR_ERR_REDEFINED_MSG	"Redefined message data: LANG=%s %ld `%s'"
#define	STR_ERR_NOT_DEFINED_MSG	"Don't defined message data: LANG=%s %ld"

typedef enum {
	LANG_KIND_ENGLISH,
	LANG_KIND_JAPANESE,
	LANG_KIND_MAX_N,
} lang_kind_t;

typedef struct {
	char	*name;
	lang_kind_t	kind;
} lang_t;

#define	LANG_TAB_MAX_N	64

lang_t	lang_tab[LANG_TAB_MAX_N] = {
	{ STR_ENGLISH, LANG_KIND_ENGLISH, },
	{ STR_JP_EUC, LANG_KIND_JAPANESE, },
	{ STR_JP_UJIS, LANG_KIND_JAPANESE, },
	{ NULL, LANG_KIND_MAX_N, },
};

typedef struct {
	n_msg_t	n;
	char	*s;
} msg_t;

msg_t	all_lang_msg[LANG_KIND_MAX_N][N_MSG_MAX_N] = {
	{
#include	"msg_eng.h"
	},
	{
#include	"msg_jpn.h"
	},
};

bool_t	flg_msg_def[N_MSG_MAX_N];

/**/

void	init_msg( void )
{
	char	*lang;
	lang_kind_t	lang_kind;
	long	k;

	n_msg_t	m;
	long	i;
	bool_t	flg_exit;

	flg_exit = FALSE;

	lang = getenv( STR_ENV_LANG );
	if( lang == NULL )
		lang = STR_DFLT_LANG;

	lang_kind = LANG_KIND_MAX_N;
	for( k = 0; k < LANG_TAB_MAX_N; k++ ){
		if( lang_tab[k].name == NULL )
			break;
		if( strcmp( lang, lang_tab[k].name ) == 0 ){
			lang_kind = lang_tab[k].kind;
			break;
		}
	}
	if( lang_kind >= LANG_KIND_MAX_N ){
		print_err( STR_ERR_LANG, lang );
		print_err( STR_S, STR_SUPPORT_LANG );
		for( k = 0; k < LANG_TAB_MAX_N; k++ ){
			if( lang_tab[k].name == NULL )
				break;
			fprintf( stderr, STR_SUPPORT_LANG_LIST,
					lang_tab[k].name );
		}
		fprintf( stderr, "\n" );
		exit_game( EXIT_FAILURE );
	}

	for( m = 0; m < N_MSG_MAX_N; m++ )
		flg_msg_def[m] = FALSE;

	for( i = 0; i < N_MSG_MAX_N; i++ ){
		if( all_lang_msg[lang_kind][i].s == NULL )
			break;

		m = all_lang_msg[lang_kind][i].n;
		if( flg_msg_def[m] ){
			char	*s;

			/* $B%a%C%;!<%8:FDj5A$5$l$F$$$k(B */
			s = all_lang_msg[lang_kind][m].s;
			print_err( STR_ERR_REDEFINED_MSG,
					lang_tab[lang_kind].name, m, s );
			flg_exit = TRUE;
		}
		ary_msg[m] = all_lang_msg[lang_kind][i].s;
		flg_msg_def[m] = TRUE;
	}

	for( m = 0; m < N_MSG_MAX_N; m++ ){
		if( !flg_msg_def[m] ){
			/* $B%a%C%;!<%8Dj5A$5$l$F$$$J$$(B */
			print_err( STR_ERR_NOT_DEFINED_MSG,
					lang_tab[lang_kind].name, m );
			flg_exit = TRUE;
		}
	}

	if( flg_exit )
		exit_game( EXIT_FAILURE );
}

/**/

==> lnl-2.1.20.tar.gz: lnl-2.1.20/src/msg.c <==
/*****************************************************************
* L&L - Labyrinths & Legends
* Copyright (c) 1993-2003 YOSHIMURA Tomohiko All rights reserved.
* 
* Created by BowKenKen
*   e-mail: bowkenken@users.sourceforge.jp
*   URL: https://sourceforge.jp/projects/lnl/
* 
* License is GPL
* 
* ܥץϥե꡼եȥǤ
* ʤϡ Free Software Foundation ɽ
*  GNU ̸ͭѵΡ֥С󣲡
* ϤʹߤγƥС椫餤줫򤷡
* ΥС˽äܥץ
* ۤޤѹ뤳ȤǤޤ
* 
* ܥץͭѤȤϻפޤۤˤäƤϡ
* ԾڤŪŬˤĤƤΰۤݾڤޤ,
* ʤݾڤԤʤޤ
* ܺ٤ˤĤƤ GNU ̸ͭѵɤߤ
* 
* ʤϡܥץȰ GNU ̸ͭѵ
* μ̤äƤϤǤǤʤϡ
*   Free Software Foundation, Inc.,
*   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
* ؼ񤤤Ƥ
* 
* $Id: msg.c,v 1.10 2003/11/19 13:19:13 bowkenken Exp $
*****************************************************************/

#include	"gmain.h"
/*#include	"misc.h"*/
/*#include	"turn.h"*/
/*#include	"dun.h"*/
/*#include	"town.h"*/
/*#include	"item.h"*/
/*#include	"spell.h"*/
/*#include	"chr.h"*/
/*#include	"party.h"*/
/*#include	"mnstr.h"*/
/*#include	"pet.h"*/
/*#include	"fight.h"*/
/*#include	"fx.h"*/
/*#include	"trap.h"*/
#include	"draw.h"
/*#include	"curs.h"*/
/*#include	"menu.h"*/
#include	"msg.h"
/*#include	"ver.h"*/
#include	"gmain_prot.h"
/*#include	"misc_prot.h"*/
/*#include	"turn_prot.h"*/
/*#include	"dun_prot.h"*/
/*#include	"town_prot.h"*/
/*#include	"item_prot.h"*/
/*#include	"spell_prot.h"*/
/*#include	"chr_prot.h"*/
/*#include	"party_prot.h"*/
/*#include	"mnstr_prot.h"*/
/*#include	"pet_prot.h"*/
/*#include	"fight_prot.h"*/
/*#include	"fx_prot.h"*/
/*#include	"trap_prot.h"*/
#include	"draw_prot.h"
/*#include	"curs_prot.h"*/
/*#include	"menu_prot.h"*/
/*#include	"tmenu_prot.h"*/
/*#include	"amenu_prot.h"*/
/*#include	"gfile_prot.h"*/
/*#include	"msg_prot.h"*/

/**/

#define	STR_S	"%s"
#define	STR_ENV_LANG	"LANG"
#define	STR_SUPPORT_LANG	"Supporting language is:"
#define	STR_SUPPORT_LANG_LIST	"\t`%s'\n"
#define	STR_ERR_LANG	"Don't support language: LANG=%s"
#define	STR_ERR_REDEFINED_MSG	"Redefined message data: LANG=%s %ld `%s'"
#define	STR_ERR_NOT_DEFINED_MSG	"Don't defined message data: LANG=%s %ld"

/* lang */

#define	LANG_TAB_MAX_N	64
#define	STR_DFLT_LANG	"ja_JP.eucJP"

typedef enum {
	LANG_KIND_ENGLISH,
	LANG_KIND_JAPANESE,
	LANG_KIND_MAX_N,
} lang_kind_t;

typedef struct {
	char	*name;
	lang_kind_t	kind;
} lang_t;

static lang_t	lang_tab[LANG_TAB_MAX_N] = {
	{ "C", LANG_KIND_ENGLISH, },
	{ "ja_JP.eucJP", LANG_KIND_JAPANESE, },
	{ "ja_JP.ujis", LANG_KIND_JAPANESE, },
	{ NULL, LANG_KIND_MAX_N, },
};

/* msg_t */

typedef struct {
	n_msg_t	n;
	char	*s;
} msg_t;

static msg_t	all_lang_msg[LANG_KIND_MAX_N][N_MSG_MAX_N] = {
	{
#include	"msg_eng.h"
	},
	{
#include	"msg_jpn.h"
	},
};

static bool_t	flg_msg_def[N_MSG_MAX_N];

/**/

void	init_msg( void )
{
	char	*lang;
	lang_kind_t	lang_kind;
	long	k;

	n_msg_t	m;
	long	i;
	bool_t	flg_exit;

	flg_exit = FALSE;

	lang = getenv( STR_ENV_LANG );
	if( lang == NULL )
		lang = STR_DFLT_LANG;

	lang_kind = LANG_KIND_MAX_N;
	for( k = 0; k < LANG_TAB_MAX_N; k++ ){
		if( lang_tab[k].name == NULL )
			break;
		if( strcmp( lang, lang_tab[k].name ) == 0 ){
			lang_kind = lang_tab[k].kind;
			break;
		}
	}
	if( lang_kind >= LANG_KIND_MAX_N ){
		print_err( STR_ERR_LANG, lang );
		print_err( STR_S, STR_SUPPORT_LANG );
		for( k = 0; k < LANG_TAB_MAX_N; k++ ){
			if( lang_tab[k].name == NULL )
				break;
			fprintf( stderr, STR_SUPPORT_LANG_LIST,
					lang_tab[k].name );
		}
		fprintf( stderr, "\n" );
		exit_game( EXIT_FAILURE );
	}

	for( m = 0; m < N_MSG_MAX_N; m++ )
		flg_msg_def[m] = FALSE;

	for( i = 0; i < N_MSG_MAX_N; i++ ){
		if( all_lang_msg[lang_kind][i].s == NULL )
			break;

		m = all_lang_msg[lang_kind][i].n;
		if( flg_msg_def[m] ){
			char	*s;

			/* åƤ */
			s = all_lang_msg[lang_kind][m].s;
			print_err( STR_ERR_REDEFINED_MSG,
					lang_tab[lang_kind].name, m, s );
			flg_exit = TRUE;
		}
		ary_msg[m] = all_lang_msg[lang_kind][i].s;
		flg_msg_def[m] = TRUE;
	}

	for( m = 0; m < N_MSG_MAX_N; m++ ){
		if( !flg_msg_def[m] ){
			/* åƤʤ */
			print_err( STR_ERR_NOT_DEFINED_MSG,
					lang_tab[lang_kind].name, m );
			flg_exit = TRUE;
		}
	}

	if( flg_exit )
		exit_game( EXIT_FAILURE );
}

/**/
